@@ -1,6 +1,6 @@
 predictionFunction <- function(method, modelFit, newdata, preProc = NULL, param = NULL)
 {
-  if(!is.null(preProc)) newdata <- predict(preProc, newdata)
+  if(!is.null(newdata) && !is.null(preProc)) newdata <- predict(preProc, newdata)
   out <- method$predict(modelFit = modelFit, 
                         newdata = newdata, 
                         submodels = param)
